@@ -5,12 +5,12 @@ from bergen.query import DelayedGQL
 
 
 CREATE_SAMPLE = DelayedGQL("""
-mutation SampleCreate($name: String) {
-  createSample(name: $name){
+mutation SampleCreate($name: String, $creator: String) {
+  createSample(name: $name, creator: $creator){
     id
     name
     creator {
-        username
+        email
     }
   }
 }
