@@ -12,6 +12,9 @@ query Representation($name: String) {
     variety
     tags
     unique
+    creator {
+      email
+    }
     sample {
       id
     }
@@ -28,6 +31,9 @@ query Representation($id: ID!){
     variety
     store
     unique
+    creator {
+      email
+    }
     sample {
       id
     }
